
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef ndd_MSG_LIB_H
#define ndd_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "nddType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  NDD_MBOX_NAME                  genomInstanceName("ndd")

#define  NDD_MAX_RQST_SIZE              136

#define  NDD_MBOX_RQST_SIZE       \
 (BUF_SIZE(NDD_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  NDD_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  NDD_MAX_REPLY_SIZE             136

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  NDD_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(NDD_MAX_REPLY_SIZE) \
   + BUF_SIZE(NDD_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define NDD_INIT_RQST 0
#define NDD_GETINIT_RQST 1
#define NDD_SETPARAMS_RQST 2
#define NDD_SETPARAMUSETHETA_RQST 3
#define NDD_GETPARAMS_RQST 4
#define NDD_SETSPEED_RQST 5
#define NDD_GETSPEED_RQST 6
#define NDD_EXECTRAJ_RQST 7
#define NDD_GOTO_RQST 8
#define NDD_GOTORELATIVE_RQST 9
#define NDD_STOP_RQST 10
#define NDD_ABORT_RQST 11


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS nddClientInit (CLIENT_ID *pClientId);

STATUS nddClientEnd (CLIENT_ID clientId);

int nddAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int nddAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int nddAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS nddInitRqstSend (CLIENT_ID clientId, int *pRqstId,
					 NDD_INPUT_POSTERS *(in_inputPosters),
					 int replyTimeOut);

extern int nddInitReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int nddInitRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					NDD_INPUT_POSTERS *(in_inputPosters), 
					
					int *activity, int *bilan);

extern int nddInitRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					NDD_INPUT_POSTERS *(in_inputPosters), 
					
					int *activity,
					int *bilan);




extern STATUS nddGetInitRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int nddGetInitReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       NDD_INPUT_POSTERS *(out_inputPosters),
			       int *bilan);

int nddGetInitRqstAndRcv (CLIENT_ID clientId, 
				  
				 NDD_INPUT_POSTERS *(out_inputPosters),
				 int *bilan);




extern STATUS nddSetParamsRqstSend (CLIENT_ID clientId, int *pRqstId,
					 NDD_PARAMS *(in_params),
					 int replyTimeOut);

extern int nddSetParamsReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int nddSetParamsRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					NDD_PARAMS *(in_params), 
					
					int *activity, int *bilan);

extern int nddSetParamsRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					NDD_PARAMS *(in_params), 
					
					int *activity,
					int *bilan);




extern STATUS nddSetParamUseThetaRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 NDD_USING_THETA *(in_useTheta),
					 int replyTimeOut);

int nddSetParamUseThetaReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int nddSetParamUseThetaRqstAndRcv (CLIENT_ID clientId, 
				 NDD_USING_THETA *(in_useTheta), 
				 
				 int *bilan);




extern STATUS nddGetParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int nddGetParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       NDD_PARAMS *(out_params),
			       int *bilan);

int nddGetParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 NDD_PARAMS *(out_params),
				 int *bilan);




extern STATUS nddSetSpeedRqstSend (CLIENT_ID clientId, int *pRqstId,
					 NDD_SPEED *(in_maxSpeed),
					 int replyTimeOut);

extern int nddSetSpeedReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int nddSetSpeedRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					NDD_SPEED *(in_maxSpeed), 
					
					int *activity, int *bilan);

extern int nddSetSpeedRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					NDD_SPEED *(in_maxSpeed), 
					
					int *activity,
					int *bilan);




extern STATUS nddGetSpeedRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int nddGetSpeedReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       NDD_SPEED *(out_maxSpeed),
			       int *bilan);

int nddGetSpeedRqstAndRcv (CLIENT_ID clientId, 
				  
				 NDD_SPEED *(out_maxSpeed),
				 int *bilan);




extern STATUS nddExecTrajRqstSend (CLIENT_ID clientId, int *pRqstId,
					 NDD_STRING *(in_trajPosterName),
					 int replyTimeOut);

extern int nddExecTrajReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int nddExecTrajRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					NDD_STRING *(in_trajPosterName), 
					
					int *activity, int *bilan);

extern int nddExecTrajRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					NDD_STRING *(in_trajPosterName), 
					
					int *activity,
					int *bilan);




extern STATUS nddGoToRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GENPOS_CART_CONFIG *(in_global_goal),
					 int replyTimeOut);

extern int nddGoToReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int nddGoToRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GENPOS_CART_CONFIG *(in_global_goal), 
					
					int *activity, int *bilan);

extern int nddGoToRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GENPOS_CART_CONFIG *(in_global_goal), 
					
					int *activity,
					int *bilan);




extern STATUS nddGoToRelativeRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GENPOS_CART_CONFIG *(in_local_goal),
					 int replyTimeOut);

extern int nddGoToRelativeReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int nddGoToRelativeRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GENPOS_CART_CONFIG *(in_local_goal), 
					
					int *activity, int *bilan);

extern int nddGoToRelativeRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GENPOS_CART_CONFIG *(in_local_goal), 
					
					int *activity,
					int *bilan);




extern STATUS nddStopRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int nddStopReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int nddStopRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* ndd_MSG_LIB_H */

